# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/appointment_template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import holidays_pb2 as v1_dot_rules_dot_holidays__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#v1/rules/appointment_template.proto\x12.pro.omni.oms.api.v1.rules.appointment_template\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x18v1/rules/warehouse.proto\x1a\x17v1/rules/holidays.proto"d\n\x18\x41ppointmentTemplateLines\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x12\n\nhour_start\x18\x02 \x01(\t\x12\x10\n\x08hour_end\x18\x03 \x01(\t\x12\x15\n\rorder_numbers\x18\x04 \x01(\x05"\xab\x04\n\x13\x41ppointmentTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\nwarehouses\x18\x03 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12J\n\x07methods\x18\x04 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x15\n\rorder_numbers\x18\x05 \x01(\x05\x12\x1b\n\x13hour_limit_same_day\x18\x06 \x01(\t\x12\x1b\n\x13number_days_to_show\x18\x07 \x01(\x05\x12>\n\x08holidays\x18\x08 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.holidays.Holidays\x12W\n\x05lines\x18\t \x03(\x0b\x32H.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateLines\x12*\n\x06\x61\x63tive\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x13\n\x0b\x65xternal_id\x18\x0b \x01(\t\x12?\n\x0cobject_audit\x18\x0c \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe6\x02\n AppointmentTemplateCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rwarehouse_ids\x18\x02 \x03(\x05\x12\x12\n\nmethod_ids\x18\x03 \x03(\t\x12\x15\n\rorder_numbers\x18\x04 \x01(\x05\x12\x1b\n\x13hour_limit_same_day\x18\x05 \x01(\t\x12\x1b\n\x13number_days_to_show\x18\x06 \x01(\x05\x12\x12\n\nholiday_id\x18\x07 \x01(\t\x12W\n\x05lines\x18\x08 \x03(\x0b\x32H.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateLines\x12\x13\n\x0b\x65xternal_id\x18\t \x01(\t\x12\x36\n\x07\x63ontext\x18\n \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n!AppointmentTemplateCreateResponse\x12\x61\n\x14\x61ppointment_template\x18\x01 \x01(\x0b\x32\x43.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplate\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfc\x02\n\x1e\x41ppointmentTemplateReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x02\n\x1f\x41ppointmentTemplateReadResponse\x12\x62\n\x15\x61ppointment_templates\x18\x01 \x03(\x0b\x32\x43.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplate\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xbd\x01\n AppointmentTemplateUpdateRequest\x12\x61\n\x14\x61ppointment_template\x18\x01 \x01(\x0b\x32\x43.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplate\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n!AppointmentTemplateUpdateResponse\x12\x61\n\x14\x61ppointment_template\x18\x01 \x01(\x0b\x32\x43.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplate\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"f\n AppointmentTemplateDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"n\n!AppointmentTemplateDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xaa\x06\n\x1a\x41ppointmentTemplateService\x12\xc2\x01\n\x19\x41ppointmentTemplateCreate\x12P.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateCreateRequest\x1aQ.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateCreateResponse"\x00\x12\xbc\x01\n\x17\x41ppointmentTemplateRead\x12N.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateReadRequest\x1aO.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateReadResponse"\x00\x12\xc2\x01\n\x19\x41ppointmentTemplateUpdate\x12P.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateUpdateRequest\x1aQ.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateUpdateResponse"\x00\x12\xc2\x01\n\x19\x41ppointmentTemplateDelete\x12P.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateDeleteRequest\x1aQ.pro.omni.oms.api.v1.rules.appointment_template.AppointmentTemplateDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.appointment_template_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_APPOINTMENTTEMPLATELINES"]._serialized_start = 221
    _globals["_APPOINTMENTTEMPLATELINES"]._serialized_end = 321
    _globals["_APPOINTMENTTEMPLATE"]._serialized_start = 324
    _globals["_APPOINTMENTTEMPLATE"]._serialized_end = 879
    _globals["_APPOINTMENTTEMPLATECREATEREQUEST"]._serialized_start = 882
    _globals["_APPOINTMENTTEMPLATECREATEREQUEST"]._serialized_end = 1240
    _globals["_APPOINTMENTTEMPLATECREATERESPONSE"]._serialized_start = 1243
    _globals["_APPOINTMENTTEMPLATECREATERESPONSE"]._serialized_end = 1452
    _globals["_APPOINTMENTTEMPLATEREADREQUEST"]._serialized_start = 1455
    _globals["_APPOINTMENTTEMPLATEREADREQUEST"]._serialized_end = 1835
    _globals["_APPOINTMENTTEMPLATEREADRESPONSE"]._serialized_start = 1838
    _globals["_APPOINTMENTTEMPLATEREADRESPONSE"]._serialized_end = 2105
    _globals["_APPOINTMENTTEMPLATEUPDATEREQUEST"]._serialized_start = 2108
    _globals["_APPOINTMENTTEMPLATEUPDATEREQUEST"]._serialized_end = 2297
    _globals["_APPOINTMENTTEMPLATEUPDATERESPONSE"]._serialized_start = 2300
    _globals["_APPOINTMENTTEMPLATEUPDATERESPONSE"]._serialized_end = 2509
    _globals["_APPOINTMENTTEMPLATEDELETEREQUEST"]._serialized_start = 2511
    _globals["_APPOINTMENTTEMPLATEDELETEREQUEST"]._serialized_end = 2613
    _globals["_APPOINTMENTTEMPLATEDELETERESPONSE"]._serialized_start = 2615
    _globals["_APPOINTMENTTEMPLATEDELETERESPONSE"]._serialized_end = 2725
    _globals["_APPOINTMENTTEMPLATESERVICE"]._serialized_start = 2728
    _globals["_APPOINTMENTTEMPLATESERVICE"]._serialized_end = 3538
# @@protoc_insertion_point(module_scope)
