# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/users/log_session.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.users import user_pb2 as v1_dot_users_dot_user__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/users/log_session.proto\x12%pro.omni.oms.api.v1.users.log_session\x1a\x11\x63ommon/base.proto\x1a\x13v1/users/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto"\xfe\x01\n\nLogSession\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x04user\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.v1.users.user.User\x12\x11\n\toperation\x18\x03 \x01(\t\x12.\n\ndate_start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x64\x61te_end\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xf3\x02\n\x15LogSessionReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe7\x01\n\x16LogSessionReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12G\n\x0clog_sessions\x18\x02 \x03(\x0b\x32\x31.pro.omni.oms.api.v1.users.log_session.LogSession\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"g\n\x13PausedMethodRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe4\x01\n\x14PausedMethodResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x46\n\x0blog_session\x18\x02 \x01(\x0b\x32\x31.pro.omni.oms.api.v1.users.log_session.LogSession\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData2\xb1\x02\n\x11LogSessionService\x12\x8f\x01\n\x0eLogSessionRead\x12<.pro.omni.oms.api.v1.users.log_session.LogSessionReadRequest\x1a=.pro.omni.oms.api.v1.users.log_session.LogSessionReadResponse"\x00\x12\x89\x01\n\x0cPausedMethod\x12:.pro.omni.oms.api.v1.users.log_session.PausedMethodRequest\x1a;.pro.omni.oms.api.v1.users.log_session.PausedMethodResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.users.log_session_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_LOGSESSION"]._serialized_start = 143
    _globals["_LOGSESSION"]._serialized_end = 397
    _globals["_LOGSESSIONREADREQUEST"]._serialized_start = 400
    _globals["_LOGSESSIONREADREQUEST"]._serialized_end = 771
    _globals["_LOGSESSIONREADRESPONSE"]._serialized_start = 774
    _globals["_LOGSESSIONREADRESPONSE"]._serialized_end = 1005
    _globals["_PAUSEDMETHODREQUEST"]._serialized_start = 1007
    _globals["_PAUSEDMETHODREQUEST"]._serialized_end = 1110
    _globals["_PAUSEDMETHODRESPONSE"]._serialized_start = 1113
    _globals["_PAUSEDMETHODRESPONSE"]._serialized_end = 1341
    _globals["_LOGSESSIONSERVICE"]._serialized_start = 1344
    _globals["_LOGSESSIONSERVICE"]._serialized_end = 1649
# @@protoc_insertion_point(module_scope)
