# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/redistribution_order.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#v1/rules/redistribution_order.proto\x12.pro.omni.oms.api.v1.rules.redistribution_order\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto"\x96\x01\n\x13RedistributionOrder\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x11\x64istribution_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12?\n\x0cobject_audit\x18\x03 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"j\n RedistributionOrderCreateRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe2\x01\n!RedistributionOrderCreateResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x61\n\x14redistribution_order\x18\x02 \x01(\x0b\x32\x43.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrder\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfc\x02\n\x1eRedistributionOrderReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x8b\x02\n\x1fRedistributionOrderReadResponse\x12\x62\n\x15redistribution_orders\x18\x01 \x03(\x0b\x32\x43.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrder\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"f\n RedistributionOrderDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x7f\n!RedistributionOrderDeleteResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xdf\x04\n\x1aRedistributionOrderService\x12\xc0\x01\n\x19RedistributionOrderAction\x12P.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderCreateRequest\x1aQ.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderCreateResponse\x12\xba\x01\n\x17RedistributionOrderRead\x12N.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderReadRequest\x1aO.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderReadResponse\x12\xc0\x01\n\x19RedistributionOrderDelete\x12P.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderDeleteRequest\x1aQ.pro.omni.oms.api.v1.rules.redistribution_order.RedistributionOrderDeleteResponseb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.redistribution_order_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    _globals["_REDISTRIBUTIONORDER"]._serialized_start = 137
    _globals["_REDISTRIBUTIONORDER"]._serialized_end = 287
    _globals["_REDISTRIBUTIONORDERCREATEREQUEST"]._serialized_start = 289
    _globals["_REDISTRIBUTIONORDERCREATEREQUEST"]._serialized_end = 395
    _globals["_REDISTRIBUTIONORDERCREATERESPONSE"]._serialized_start = 398
    _globals["_REDISTRIBUTIONORDERCREATERESPONSE"]._serialized_end = 624
    _globals["_REDISTRIBUTIONORDERREADREQUEST"]._serialized_start = 627
    _globals["_REDISTRIBUTIONORDERREADREQUEST"]._serialized_end = 1007
    _globals["_REDISTRIBUTIONORDERREADRESPONSE"]._serialized_start = 1010
    _globals["_REDISTRIBUTIONORDERREADRESPONSE"]._serialized_end = 1277
    _globals["_REDISTRIBUTIONORDERDELETEREQUEST"]._serialized_start = 1279
    _globals["_REDISTRIBUTIONORDERDELETEREQUEST"]._serialized_end = 1381
    _globals["_REDISTRIBUTIONORDERDELETERESPONSE"]._serialized_start = 1383
    _globals["_REDISTRIBUTIONORDERDELETERESPONSE"]._serialized_end = 1510
    _globals["_REDISTRIBUTIONORDERSERVICE"]._serialized_start = 1513
    _globals["_REDISTRIBUTIONORDERSERVICE"]._serialized_end = 2120
# @@protoc_insertion_point(module_scope)
